@@ -1,5 +1,5 @@
 (* Unison file synchronizer: src/files.ml *)
-(* Copyright 1999-2016, Benjamin C. Pierce
+(* Copyright 1999-2017, Benjamin C. Pierce
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -46,11 +46,20 @@ let writeCommitLog source target tempname =
        Printf.fprintf c "(and delete this notice when you've done so).\n";
        close_out c)
 
-let clearCommitLog () =
+let clearCommitLog pathTo =
   debug (fun() -> (Util.msg "Deleting commit log\n"));
+
+  let tmpPathDir = Fspath.canonize (Some Util.homeDirStr) in  (* tmpPathDir is a Fspath.t *)
+  (* Use pathTo in the temporary name (instead of DANGER.README) to reduce chance of reuse *)
+  let tmpPath = Os.tempPath tmpPathDir pathTo in  (* tmpPath is a Path.local *)
+  let dangerFspath = Fspath.canonize (Some (System.fspathToString commitLogName)) in
+  let dangerFsPathTmp = Fspath.concat tmpPathDir tmpPath in
+
+  Os.renameFspath "DANGER.README" dangerFspath dangerFsPathTmp;
+  
   Util.convertUnixErrorsToFatal
     "clearing commit log"
-      (fun () -> System.unlink commitLogName)
+      (fun () -> System.unlink (System.fspathFromString (Fspath.toString dangerFsPathTmp)) )
 
 let processCommitLog () =
   if System.file_exists commitLogName then begin
@@ -280,7 +289,7 @@ let performRename fspathTo localPathTo workingDir pathFrom pathTo prevArch =
                        (Fspath.toDebugString target));
               Os.rename "renameLocal(2)"
                 source Path.empty target Path.empty))
-          (fun _ -> clearCommitLog());
+          (fun _ -> clearCommitLog pathTo);
         (* It is ok to leave a temporary file.  So, the log can be
            cleared before deleting it. *)
         Os.delete temp Path.empty
@@ -377,7 +386,8 @@ let rec createDirectories fspath localPath props =
           createDirectories fspath parentPath rem;
           try
             let absolutePath = Fspath.concat fspath parentPath in
-             Fs.mkdir absolutePath (Props.perms desc)
+             Fs.mkdir absolutePath (Props.perms desc);
+             Fileinfo.set fspath parentPath (`Copy parentPath) desc
             (* The directory may have already been created
                if there are several paths with the same prefix *)
           with Unix.Unix_error (Unix.EEXIST, _, _) -> ()
@@ -452,15 +462,12 @@ let deleteSpuriousChildrenLocal (_, (fspathTo, pathTo, archChildren)) =
 let deleteSpuriousChildren =
   Remote.registerRootCmd "deleteSpuriousChildren" deleteSpuriousChildrenLocal
 
-let rec normalizePropsRec propsFrom propsTo =
+let rec normalizeProps propsFrom propsTo =
   match propsFrom, propsTo with
-    d :: r, d' :: r' -> normalizePropsRec r r'
-  | _, []            -> propsFrom
+    d :: r, d' :: r' -> normalizeProps r r'
+  | _, []            -> (Safelist.rev propsFrom)
   | [], _ :: _       -> assert false
 
-let normalizeProps propsFrom propsTo =
-  normalizePropsRec (Safelist.rev propsFrom) (Safelist.rev propsTo)
-
 (* ------------------------------------------------------------ *)
 
 let copyReg = Lwt_util.make_region 50
