@@ -1,5 +1,5 @@
 (* Unison file synchronizer: src/remote.ml *)
-(* Copyright 1999-2016, Benjamin C. Pierce
+(* Copyright 1999-2017, Benjamin C. Pierce
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -450,7 +450,12 @@ let defaultMarshalingFunctions =
      let s = Bytearray.marshal data [Marshal.No_sharing] in
      let l = Bytearray.length s in
      ((s, 0, l) :: rem, l)),
-  (fun buf pos -> Bytearray.unmarshal buf pos)
+  (fun buf pos ->
+      try Bytearray.unmarshal buf pos
+      with Failure s -> raise (Util.Fatal (Printf.sprintf 
+"Fatal error during unmarshaling (%s),
+possibly because client and server have been compiled with different\
+versions of the OCaml compiler." s)))
 
 let makeMarshalingFunctions payloadMarshalingFunctions string =
   let (marshalPayload, unmarshalPayload) = payloadMarshalingFunctions in
@@ -910,7 +915,16 @@ let commandAvailable =
                      BUILDING CONNECTIONS TO THE SERVER
  ****************************************************************************)
 
-let connectionHeader = "Unison " ^ Uutil.myMajorVersion ^ "\n"
+let connectionHeader =
+  let (major,minor,patchlevel) =
+    Scanf.sscanf Sys.ocaml_version "%d.%d.%d" (fun x y z -> (x,y,z)) in
+  let compiler =
+    if    major < 4 
+       || major = 4 && minor <= 2
+       || major = 4 && minor = 2 && patchlevel <= 1
+    then "<= 4.01.1"
+    else ">= 4.01.2"
+  in "Unison " ^ Uutil.myMajorVersion ^ " with OCaml " ^ compiler ^ "\n"
 
 let rec checkHeader conn buffer pos len =
   if pos = len then
@@ -1408,7 +1422,7 @@ let commandLoop in_ch out_ch =
        match e with
          Util.Fatal "Lost connection with the server" ->
            debug (fun () -> Util.msg "Connection closed by the client\n");
-           (* We prevents new writes and wait for any current write to
+           (* We prevent new writes and wait for any current write to
               terminate.  As we don't have a good way to wait for the
               writer to terminate, we just yield a bit. *)
            let rec wait n =
