@@ -1,5 +1,5 @@
 (* Unison file synchronizer: src/test.ml *)
-(* Copyright 1999-2016, Benjamin C. Pierce
+(* Copyright 1999-2017, Benjamin C. Pierce
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -332,7 +332,9 @@ let test() =
       let orig = (Dir ["foo", Dir [".git", Dir ["a", File "foo";
                                                 "b", File "bar";
                                                 "c", File "baz"]]]) in
-      put R1 orig; put R2 orig; sync();
+      put R1 orig;
+      Unix.sleep 2; (* in case time granularity is coarse on this FS *)
+      put R2 orig; sync();
       let expected = (Dir ["foo", Dir [".git", Dir ["a", File "modified on R1";
                                                     "b", File "bar";
                                                     "c", File "modified on R1"]]]) in
@@ -340,6 +342,7 @@ let test() =
                                Dir ["a", File "foo";
                                     "b", File "modified on R2";
                                     "c", File "modified on R2"]]]);
+      Unix.sleep 2; 
       put R1 expected;
       sync ();
       check "1" R2 expected;
@@ -522,6 +525,21 @@ let test() =
       put R1 (Dir ["y", Link "x"]); sync();
       check "1" R2 orig;
     );
+
+    (* Check for the bug reported by Sebastian Elsner (Jan 2017) *)
+    (* NOT POSSIBLE because the test API does not enable one to play with file
+       owners, but I put the test here anyway. *)
+    (*
+    runtest "owner of path directories" ["owner"; "path = a/b"] (fun() ->
+      put R1 (Dir ["a", Dir ["b", Dir["foo", File "Foo";
+                                      "bar", File "Bar";
+                                      "baz", File "Baz";]]]]);
+      setOwner R1 "a/b" "testuser";  (* does not exist *)
+      put R2 (Dir []);
+      sync();
+      checkOwner "1" R2 "a/b" "testuser";  (* does not exist *)
+    );
+    *)
   end;
 
   if !failures = 0 then
