@@ -1,5 +1,5 @@
 (* Unison file synchronizer: src/uicommon.ml *)
-(* Copyright 1999-2016, Benjamin C. Pierce
+(* Copyright 1999-2017, Benjamin C. Pierce
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -15,7 +15,6 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *)
 
-
 open Common
 open Lwt
 
@@ -85,7 +84,7 @@ let contactquietly =
      ^ "during startup.")
 
 let contactingServerMsg () =
-  Printf.sprintf "Contacting server..."
+  Printf.sprintf "Unison %s: Contacting server..." Uutil.myVersion 
 
 let repeat =
   Prefs.createString "repeat" ""
@@ -291,7 +290,7 @@ let reconItem2stringList oldPath theRI =
       (replicaContent2shortString diff.rc1,
        direction2action partial diff.direction,
        replicaContent2shortString diff.rc2,
-       displayPath oldPath theRI.path1)
+       Path.toString theRI.path1)
 
 let reconItem2string oldPath theRI status =
   let (r1, action, r2, path) = reconItem2stringList oldPath theRI in
